Introduction
============

`RabbitMQ <https://www.rabbitmq.com/>`_ is an Open Source message broker which supports `AMQP <https://en.wikipedia.org/wiki/Advanced_Message_Queuing_Protocol>`_, `STOMP <https://en.wikipedia.org/wiki/Streaming_Text_Oriented_Messaging_Protocol>`_ and `MQTT <https://en.wikipedia.org/wiki/MQTT>`_ protocols.

This Ansible role can be used to install and manage RabbitMQ service on
Debian/Ubuntu hosts.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.3.0``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.rabbitmq_server


..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
